@@ -84,13 +84,13 @@
     </message>
     <message>
         <location filename="settingsdialog.cpp" line="77"/>
-        <source>Thank you for installing profile changer widget.</source>
-        <translation>Vielen Dank, dass Sie das Profilwechsel Widget installiert haben.</translation>
+        <source>Thank you for installing profile changer widget version %1.</source>
+        <translation>Vielen Dank, dass Sie das Profilwechsel Widget Version %1 installiert haben.</translation>
     </message>
     <message>
         <location filename="settingsdialog.cpp" line="80"/>
-        <source>Thank you for updating profile changer widget.</source>
-        <translation>Vielen Dank, dass Sie das Profilwechsel Widget aktualisiert haben.</translation>
+        <source>Thank you for updating profile changer widget from version %1 to %2.</source>
+        <translation type="unfinished">Vielen Dank, dass Sie das Profilwechsel Widget von Version %1 auf 2s aktualisiert haben.</translation>
     </message>
     <message>
         <location filename="settingsdialog.cpp" line="83"/>
@@ -102,5 +102,10 @@
         <source>Therefore you can use the &quot;Feedback&quot; button.</source>
         <translation>Auf die Website gelangen Sie durch Drücken des &quot;Feedback&quot; Knopfs.</translation>
     </message>
+    <message>
+        <location filename="settingsdialog.cpp" line="106"/>
+        <source>Not yet implemented.</source>
+        <translation type="unfinished">Noch nicht implementiert.</translation>
+    </message>
 </context>
 </TS>
