@@ -7,12 +7,16 @@
 #include <QDBusInterface>
 
 #define PCW_SETTING_HEIGHT "profilechangerwidget/height"
+#define PCW_SETTING_HEIGHT_DEFAULT 72
 #define PCW_SETTING_WIDTH "profilechangerwidget/width"
+#define PCW_SETTING_WIDTH_DEFAULT 72
 #define PCW_SETTING_OPACITY "profilechangerwidget/opacity"
+#define PCW_SETTING_OPACITY_DEFAULT 70
 #define PCW_SETTING_SHOWNEXTPROFILE "profilechangerwidget/showNextProfile"
+#define PCW_SETTING_SHOWNEXTPROFILE_DEFAULT true
 #define PCW_SETTING_LASTVERSION "profilechangerwidget/lastVersion"
 #define PCW_SETTING_LASTVERSION_DEFAULT "0.0"
-#define PCW_APP_VERSION "0.9.4"
+#define PCW_APP_VERSION "0.9.5"
 
 namespace Ui {
     class SettingsDialog;
